/*
 * NewsBean.java
 *
 * Created on May 20, 2003, 3:43 PM
 */

package com.opencms.modules.homepage.news;

import java.beans.*;
import java.sql.*;
import java.io.*;
import java.net.*;
import java.util.*;
import java.util.Properties;

/**
 *
 * @author  renehinojosa
 */
public class NewsBean extends Object implements java.io.Serializable {
    
    private String dbDriver;    
    
    private String dbURL;
    
    private String dbUser;
    
    private String dbPassword;
    
    private String newsSql = "SELECT * FROM news_entry ORDER BY channel,date ";
    
    private String itemSql = "SELECT * FROM news_entry WHERE id = ?";
    
    private String channelSql = "SELECT * FROM news_entry WHERE channel = ?";
    
    private Connection connection = null;
    
    private PreparedStatement newsStatement = null;
    
    private PreparedStatement itemStatement = null;
    
    private PreparedStatement channelStatement = null;
    
    private NewsItem newsItem;
    
    /** Creates new NewsBean */
    public NewsBean() {
        init();
    }


    
    public void init() {
        // Load properties file
        try {
            String propsFileName = "NewsBean.properties";
            InputStream is = getClass().getResourceAsStream(propsFileName);
            Properties p = new Properties();
            p.load(is);
            
            this.dbDriver = p.getProperty("dbDriver");
            this.dbURL = p.getProperty("dbURL");
            this.dbUser = p.getProperty("dbUser");
            this.dbPassword = p.getProperty("dbPassword");
            
        } catch (Exception e) {
            System.err.println("unable to load Properties");
        }
        try {
            Class.forName(this.dbDriver);
            connection = DriverManager.getConnection(this.dbURL, this.dbUser, this.dbPassword);
            itemStatement = connection.prepareStatement(itemSql);
            channelStatement = connection.prepareStatement(channelSql);
        } catch (ClassNotFoundException e){
            System.err.println("Unable to load DB Driver");
        } catch (SQLException s) {
          System.err.println("Unable to connect to database "+this.dbURL);   
        }
    }   
/** Returns all news items regardless of channel*/
    public Vector getList() {
        try {
            Vector list = new Vector();
            ResultSet results;
            java.sql.Statement st = connection.createStatement();
            results = st.executeQuery("SELECT * FROM news_entry");
            while (results.next())
                list.add(makeNewsItem(results));
            return list;
        } catch (SQLException se) {
            Vector list = new Vector();
            list.add("This sucks");
            return list; }
    }
/** Returns all news items specific to channel*/    
    public Vector getList(int channel) {
        try {
            Vector list = new Vector();
            ResultSet results;
            synchronized(channelStatement) {
                channelStatement.clearParameters();
                channelStatement.setInt(1, channel);
                results = channelStatement.executeQuery();
            }
            while (results.next())
                list.add(makeNewsItem(results));
            return list;
        } catch (SQLException se) { return null;}
    }

/** Returns a NewsItem bean specific to its id */
    public NewsItem getNews(int newsID) {
        try {
            ResultSet results;
            synchronized (itemStatement){
                itemStatement.clearParameters();
                itemStatement.setInt(1,newsID);
                results = itemStatement.executeQuery();
            }
            NewsItem bean = null;
            if (results.next()) {
                bean = makeNewsItem(results);
            }
            if (results != null)
                results.close();
            return bean;
        } catch (SQLException se) {return null;}
    }

// cleans up after making a mess ;)
    public void destroy() {
        try {
            if (connection != null)
                connection.close();
        } catch (SQLException e) {}
    }
    
// fills the NewsItem bean with all the useful info    
    public NewsItem makeNewsItem(ResultSet results) throws SQLException {
        NewsItem bean = new NewsItem(results.getInt("id"));
        bean.setHeadline(results.getString("headline"));
        bean.setDescription(results.getString("description"));
        bean.setN_text(results.getString("text"));
        bean.setN_author(results.getString("author"));
        bean.setN_link(results.getString("link"));
        bean.setN_linkText(results.getString("linkText"));
        bean.setN_date(results.getDate("date"));
        bean.setN_lockState(results.getInt("lockstate"));
        bean.setN_channel(results.getInt("channel"));
        bean.setA_info1(results.getString("a_info1"));
        bean.setA_info2(results.getString("a_info2"));
        bean.setA_info3(results.getString("a_info3"));
        return bean;
    }
    
}
